function fbr --description 'Git browse commits'
  set -l log_line_to_hash "echo {} | grep -o '[a-f0-9]\{7\}' | head -1"
  set -l view_commit "$log_line_to_hash | xargs -I % sh -c 'git show --color=always % | delta | less -R'"
  set -l copy_commit_hash "$log_line_to_hash | xclip"
  set -l git_checkout "$log_line_to_hash | xargs -I % sh -c 'git checkout %'"
  set -l open_cmd "open"

  if test (uname) = Linux
    set open_cmd "xdg-open"
  end

  set github_open "$log_line_to_hash | xargs -I % sh -c '$open_cmd https://github.\$(git config remote.origin.url | cut -f2 -d. | tr \':\' /)/commit/%'"

  git log --color=always --format='%C(auto)%h%d %s %C(green)%C(bold)%cr% C(blue)%an' | \
      fzf --exact --no-sort --reverse --tiebreak=index --no-multi --ansi \
          --preview="$view_commit" \
          --header="ENTER to view, CTRL-Y to copy hash, CTRL-O to open on GitHub, CTRL-X to checkout, CTRL-C to exit" \
          --bind "enter:execute:$view_commit" \
          --bind "ctrl-y:execute:$copy_commit_hash" \
          --bind "ctrl-x:execute:$git_checkout" \
          --bind "ctrl-o:execute:$github_open"
end
